37a331259beee4fa8ebe7aa7f4d5b9d765a14c7f
kent
  Thu Jan 6 15:45:34 2011 -0800
Starting to make hgHubConnect talk with hgTracks and hgTrackUi.  Right now the tracks appear on the track list, but are not displaying properly.
diff --git src/hg/inc/trackHub.h src/hg/inc/trackHub.h
index 8a53385..ab12aca 100644
--- src/hg/inc/trackHub.h
+++ src/hg/inc/trackHub.h
@@ -37,32 +37,33 @@
      * name of hub in cart. */
     char *name;
     };
 
 struct trackHubGenome
 /* A genome serviced within a track hub. */
     {
     struct trackHubGenome *next;
     char *name;	/* Something like hg18 or mm9 - a UCSC assembly database name. */
     char *trackDbFile;	/* The base trackDb.ra file. */
     };
 
 void trackHubClose(struct trackHub **pHub);
 /* Close up and free resources from hub. */
 
-struct trackHub *trackHubOpen(char *url);
-/* Open up a track hub from url.  Reads and parses hub.ra and the genomesFile. */
+struct trackHub *trackHubOpen(char *url, char *hubName);
+/* Open up a track hub from url.  Reads and parses hub.ra and the genomesFile. 
+ * The hubName is generally just the asciified ID number. */
 
 struct trackHubGenome *trackHubFindGenome(struct trackHub *hub, char *genomeName);
 /* Return trackHubGenome of given name associated with hub.  Return NULL if no
  * such genome. */
 
 struct trackDb *trackHubTracksForGenome(struct trackHub *hub, struct trackHubGenome *genome);
 /* Get list of tracks associated with genome.  Check that it only is composed of legal
  * types.  Do a few other quick checks to catch errors early. */
 
 void trackHubAddNamePrefix(char *hubName, struct trackDb *tdbList);
 /* For a hub named "xyz" add the prefix "hub_xyz_" to each track and parent field. 
  * This is useful to the genome browser which directly puts tracks into it's
  * user settings name space.... */
 
 void trackHubAddGroupName(char *hubName, struct trackDb *tdbList);